Module: Bootscript::Chef
- Defined in:
- lib/bootscript/chef.rb
Overview
provides built-in Chef templates and attributes
Class Method Summary collapse
-
.files(erb_vars) ⇒ Object
returns a map of the built-in Chef templates, in the context of erb_vars The presence of :chef_validation_pem triggers the inclusion of Chef.
-
.included?(erb_vars = {}) ⇒ Boolean
defines whether or not Chef support will be included in the boot script, based on the presence of a certain key or keys in erb_vars.
Class Method Details
.files(erb_vars) ⇒ Object
returns a map of the built-in Chef templates, in the context of erb_vars The presence of :chef_validation_pem triggers the inclusion of Chef
7 8 9 10 11 12 13 |
# File 'lib/bootscript/chef.rb', line 7 def self.files(erb_vars) if Bootscript.windows?(erb_vars) files_for_windows(erb_vars) else files_for_unix(erb_vars) end end |
.included?(erb_vars = {}) ⇒ Boolean
defines whether or not Chef support will be included in the boot script, based on the presence of a certain key or keys in erb_vars
19 20 21 |
# File 'lib/bootscript/chef.rb', line 19 def self.included?(erb_vars = {}) erb_vars.has_key? :chef_validation_pem end |